package nl.ivojonker.p8export;

import java.io.BufferedReader;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.Properties;

import nl.ivojonker.p8export.excel.Export;
import nl.ivojonker.p8export.filenet.Connection;

import com.filenet.api.collection.RepositoryRowSet;
import com.filenet.api.core.ObjectStore;

/**
 * Simple application for exporting CE Query results to excel.
 * 
 * @author ivo jonker(.nl)
 * 
 */
public class Application {

	private ObjectStore objectStore;
	private Properties properties ;
	
	private BufferedReader consoleReader = new BufferedReader(new InputStreamReader(System.in));

	private Application () throws IOException{ 
		loadProperties();
		connect();
	}


	private void loadProperties() throws IOException{
		InputStream propertiesStream =  this.getClass().getClassLoader().getResourceAsStream("connection.properties");
		this.properties = new Properties();
		this.properties.load(propertiesStream);

		if (propertiesStream!=null)
			propertiesStream.close();
	}


	private void connect() throws IOException{
		String p8Url = this.properties.getProperty("ce.url");
		String jaas = this.properties.getProperty("ce.jaas");
		String objectstoreName = this.properties.getProperty("ce.objectstoreName");

		System.out.println("Will try to connect to: "+objectstoreName+"@"+p8Url);
		System.out.print("Please provide a username: ");
		String username = consoleReader.readLine();
		System.out.print("Password: ");
		String password = consoleReader.readLine();

		System.out.println("Connecting & logging in...");

		this.objectStore=Connection.connectToObjectStore(p8Url, username, password, jaas, objectstoreName);
	}


	private void executeToXLS() throws IOException{
		System.out.println("");
		System.out.println("Please paste the query to be executed: ");
		
		StringBuilder query = new StringBuilder();
		String reading;
		while ((reading=consoleReader.readLine()).trim().length()>0)
			query.append(" "+reading);
	
		
		RepositoryRowSet queryResults = Connection.executeQuery(query.toString(), this.objectStore);
		 
		System.out.println("Executed the query succesfully.");
		System.out.println("Provide a name for the output xls:");
		String filenameOut = consoleReader.readLine();
		filenameOut += filenameOut.toLowerCase().endsWith(".xls") ? "" : ".xls"; 
		
		System.out.println("Exporting..");
		Export.writeResults(queryResults,new File(filenameOut));
		
		System.out.println("done with best regards from Ivo Jonker :)");
		
	}


	public static void main(String[] args) throws IOException{
		Application app = new Application();
		app.executeToXLS();
	}

}
